@@ -31,7 +31,6 @@ double stc_constant( const char* name, int arg )
     switch( fl )
     {
     case '4':
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_4GL_BLOCK );
         r( wxSTC_4GL_BLOCK_ );
         r( wxSTC_4GL_CHARACTER );
@@ -64,7 +63,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_4GL_STRING_ );
         r( wxSTC_4GL_WORD );
         r( wxSTC_4GL_WORD_ );
-#endif
         break;
     case 'A':
         r( wxSTC_AVE_DEFAULT );
@@ -94,13 +92,10 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_ASM_REGISTER );
         r( wxSTC_ASM_DIRECTIVE );
         r( wxSTC_ASM_DIRECTIVEOPERAND );
-#if WXPERL_W_VERSION_GE( 2, 5, 2 )
         r( wxSTC_ASM_COMMENTBLOCK );
         r( wxSTC_ASM_CHARACTER );
         r( wxSTC_ASM_STRINGEOL );
         r( wxSTC_ASM_EXTINSTRUCTION );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_ABAQUS_ARGUMENT );
         r( wxSTC_ABAQUS_COMMAND );
         r( wxSTC_ABAQUS_COMMENT );
@@ -114,17 +109,14 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_ABAQUS_STARCOMMAND );
         r( wxSTC_ABAQUS_STRING );
         r( wxSTC_ABAQUS_WORD );
-#endif
         r( wxSTC_ADA_CHARACTEREOL );
         r( wxSTC_ADA_COMMENTLINE );
         r( wxSTC_ADA_DELIMITER );
         r( wxSTC_ADA_ILLEGAL );
         r( wxSTC_ADA_LABEL );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_ALPHA_NOALPHA );
         r( wxSTC_ALPHA_OPAQUE );
         r( wxSTC_ALPHA_TRANSPARENT );
-#endif
         r( wxSTC_APDL_COMMAND );
         r( wxSTC_APDL_COMMENT );
         r( wxSTC_APDL_COMMENTBLOCK );
@@ -132,15 +124,12 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_APDL_FUNCTION );
         r( wxSTC_APDL_NUMBER );
         r( wxSTC_APDL_PROCESSOR );
-#if WXPERL_W_VERSION_GE( 2, 6, 0 )
         r( wxSTC_APDL_ARGUMENT );
         r( wxSTC_APDL_OPERATOR );
         r( wxSTC_APDL_SLASHCOMMAND );
         r( wxSTC_APDL_STARCOMMAND );
-#endif
         r( wxSTC_APDL_STRING );
         r( wxSTC_APDL_WORD );
-#if WXPERL_W_VERSION_GE( 2, 6, 0 )
         r( wxSTC_ASN1_ATTRIBUTE );
         r( wxSTC_ASN1_COMMENT );
         r( wxSTC_ASN1_DEFAULT );
@@ -152,8 +141,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_ASN1_SCALAR );
         r( wxSTC_ASN1_STRING );
         r( wxSTC_ASN1_TYPE );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_ASY_CHARACTER );
         r( wxSTC_ASY_COMMENT );
         r( wxSTC_ASY_COMMENTLINE );
@@ -166,7 +153,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_ASY_STRINGEOL );
         r( wxSTC_ASY_WORD );
         r( wxSTC_ASY_WORD2 );
-#endif
         r( wxSTC_AU3_COMMENT );
         r( wxSTC_AU3_COMMENTBLOCK );
         r( wxSTC_AU3_DEFAULT );
@@ -177,15 +163,11 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_AU3_OPERATOR );
         r( wxSTC_AU3_PREPROCESSOR );
         r( wxSTC_AU3_SENT );
-#if WXPERL_W_VERSION_GE( 2, 6, 0 )
         r( wxSTC_AU3_SPECIAL );
-#endif
         r( wxSTC_AU3_STRING );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_AU3_COMOBJ );
         r( wxSTC_AU3_EXPAND );
         r( wxSTC_AU3_UDF );
-#endif
         r( wxSTC_AU3_VARIABLE );
         r( wxSTC_AVE_WORD1 );
         r( wxSTC_AVE_WORD2 );
@@ -229,12 +211,10 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_B_KEYWORD3 );
         r( wxSTC_B_KEYWORD4 );
         r( wxSTC_B_STRINGEOL );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_B_BINNUMBER );
         r( wxSTC_B_ERROR );
         r( wxSTC_B_HEXNUMBER );
         r( wxSTC_B_LABEL );
-#endif
         break;
     case 'C':
         r( wxSTC_CHARSET_ANSI );
@@ -256,10 +236,8 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_CHARSET_ARABIC );
         r( wxSTC_CHARSET_VIETNAMESE );
         r( wxSTC_CHARSET_THAI );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_CHARSET_8859_15 );
         r( wxSTC_CHARSET_CYRILLIC );
-#endif
         r( wxSTC_CASE_MIXED );
         r( wxSTC_CASE_UPPER );
         r( wxSTC_CASE_LOWER );
@@ -273,11 +251,9 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_CARET_STRICT );
         r( wxSTC_CARET_JUMPS );
         r( wxSTC_CARET_EVEN );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_CARETSTYLE_BLOCK );
         r( wxSTC_CARETSTYLE_INVISIBLE );
         r( wxSTC_CARETSTYLE_LINE );
-#endif
         r( wxSTC_C_DEFAULT );
         r( wxSTC_C_COMMENT );
         r( wxSTC_C_COMMENTLINE );
@@ -318,9 +294,7 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_CMD_LINEDOWNEXTEND );
         r( wxSTC_CMD_LINEUP );
         r( wxSTC_CMD_LINEUPEXTEND );
-#if WXPERL_W_VERSION_GE( 2, 5, 1 )
         r( wxSTC_CMD_LINECOPY );
-#endif
         r( wxSTC_CMD_CHARLEFT );
         r( wxSTC_CMD_CHARLEFTEXTEND );
         r( wxSTC_CMD_CHARRIGHT );
@@ -392,13 +366,8 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_CSS_DIRECTIVE );
         r( wxSTC_CSS_DOUBLESTRING );
         r( wxSTC_CSS_SINGLESTRING );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_CSS_ATTRIBUTE );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 6, 0 )
         r( wxSTC_CSS_IDENTIFIER2 );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_CAML_CHAR );
         r( wxSTC_CAML_COMMENT );
         r( wxSTC_CAML_COMMENT1 );
@@ -414,7 +383,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_CAML_OPERATOR );
         r( wxSTC_CAML_STRING );
         r( wxSTC_CAML_TAGNAME );
-#endif
         r( wxSTC_CLW_ATTRIBUTE );
         r( wxSTC_CLW_BUILTIN_PROCEDURES_FUNCTION );
         r( wxSTC_CLW_COMMENT );
@@ -426,15 +394,12 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_CLW_LABEL );
         r( wxSTC_CLW_PICTURE_STRING );
         r( wxSTC_CLW_REAL_CONSTANT );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_CLW_DEPRECATED );
         r( wxSTC_CLW_RUNTIME_EXPRESSIONS );
-#endif
         r( wxSTC_CLW_STANDARD_EQUATE );
         r( wxSTC_CLW_STRING );
         r( wxSTC_CLW_STRUCTURE_DATA_TYPE );
         r( wxSTC_CLW_USER_IDENTIFIER );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_CMAKE_COMMANDS );
         r( wxSTC_CMAKE_COMMENT );
         r( wxSTC_CMAKE_DEFAULT );
@@ -450,12 +415,9 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_CMAKE_USERDEFINED );
         r( wxSTC_CMAKE_VARIABLE );
         r( wxSTC_CMAKE_WHILEDEF );
-#endif
         r( wxSTC_CMD_CHARLEFTRECTEXTEND );
         r( wxSTC_CMD_CHARRIGHTRECTEXTEND );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_CMD_DELWORDRIGHTEND );
-#endif
         r( wxSTC_CMD_HOMERECTEXTEND );
         r( wxSTC_CMD_HOMEWRAP );
         r( wxSTC_CMD_HOMEWRAPEXTEND );
@@ -480,7 +442,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_CMD_WORDRIGHTENDEXTEND );
         r( wxSTC_CP_DBCS );
         r( wxSTC_CP_UTF8 );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_CSOUND_ARATE_VAR );
         r( wxSTC_CSOUND_COMMENT );
         r( wxSTC_CSOUND_COMMENTBLOCK );
@@ -497,7 +458,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_CSOUND_PARAM );
         r( wxSTC_CSOUND_STRINGEOL );
         r( wxSTC_CSOUND_USERKEYWORD );
-#endif
         break;
     case 'D':
         r( wxSTC_DIFF_DEFAULT );
@@ -507,7 +467,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_DIFF_POSITION );
         r( wxSTC_DIFF_DELETED );
         r( wxSTC_DIFF_ADDED );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_D_CHARACTER );
         r( wxSTC_D_COMMENT );
         r( wxSTC_D_COMMENTDOC );
@@ -526,7 +485,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_D_WORD );
         r( wxSTC_D_WORD2 );
         r( wxSTC_D_WORD3 );
-#endif
         break;
     case 'E':
         r( wxSTC_EOL_CR );
@@ -569,9 +527,7 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_ERLANG_NUMBER );
         r( wxSTC_ERLANG_OPERATOR );
         r( wxSTC_ERLANG_RECORD );
-#if WXPERL_W_VERSION_LT( 2, 9, 1 )
-        r( wxSTC_ERLANG_SEPARATOR );
-#endif
+        r( wxSTC_ERLANG_PREPROC );
         r( wxSTC_ERLANG_STRING );
         r( wxSTC_ERLANG_UNKNOWN );
         r( wxSTC_ERLANG_VARIABLE );
@@ -579,14 +535,10 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_ERR_ELF );
         r( wxSTC_ERR_IFC );
         r( wxSTC_ERR_IFORT );
-#if WXPERL_W_VERSION_GE( 2, 6, 0 )
         r( wxSTC_ERR_JAVA_STACK );
-#endif
         r( wxSTC_ERR_PHP );
         r( wxSTC_ERR_TIDY );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_ERR_VALUE );
-#endif
         r( wxSTC_ESCRIPT_BRACE );
         r( wxSTC_ESCRIPT_COMMENT );
         r( wxSTC_ESCRIPT_COMMENTDOC );
@@ -609,7 +561,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_FOLDLEVELWHITEFLAG );
         r( wxSTC_FOLDLEVELHEADERFLAG );
         r( wxSTC_FOLDLEVELNUMBERMASK );
-#if WXPERL_W_VERSION_GE( 2, 5, 2 )
         r( wxSTC_FORTH_DEFAULT );
         r( wxSTC_FORTH_COMMENT );
         r( wxSTC_FORTH_COMMENT_ML );
@@ -622,7 +573,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_FORTH_NUMBER );
         r( wxSTC_FORTH_STRING );
         r( wxSTC_FORTH_LOCALE );
-#endif
         r( wxSTC_F_DEFAULT );
         r( wxSTC_F_COMMENT );
         r( wxSTC_F_NUMBER );
@@ -639,21 +589,11 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_F_LABEL );
         r( wxSTC_F_CONTINUATION );
         r( wxSTC_FIND_POSIX );
-#if WXPERL_W_VERSION_LT( 2, 9, 1 )
-        r( wxSTC_FOLDFLAG_BOX );
-#endif
         r( wxSTC_FOLDFLAG_LEVELNUMBERS );
         r( wxSTC_FOLDFLAG_LINEAFTER_CONTRACTED );
         r( wxSTC_FOLDFLAG_LINEAFTER_EXPANDED );
         r( wxSTC_FOLDFLAG_LINEBEFORE_CONTRACTED );
         r( wxSTC_FOLDFLAG_LINEBEFORE_EXPANDED );
-#if WXPERL_W_VERSION_LT( 2, 9, 1 )
-        r( wxSTC_FOLDLEVELBOXFOOTERFLAG );
-        r( wxSTC_FOLDLEVELBOXHEADERFLAG );
-        r( wxSTC_FOLDLEVELCONTRACTED );
-        r( wxSTC_FOLDLEVELUNINDENT );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_FS_ASM );
         r( wxSTC_FS_BINNUMBER );
         r( wxSTC_FS_COMMENT );
@@ -678,10 +618,8 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_FS_PREPROCESSOR );
         r( wxSTC_FS_STRING );
         r( wxSTC_FS_STRINGEOL );
-#endif
         break;
     case 'G':
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_GAP_CHAR );
         r( wxSTC_GAP_COMMENT );
         r( wxSTC_GAP_DEFAULT );
@@ -694,7 +632,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_GAP_OPERATOR );
         r( wxSTC_GAP_STRING );
         r( wxSTC_GAP_STRINGEOL );
-#endif
         r( wxSTC_GC_ATTRIBUTE );
         r( wxSTC_GC_COMMAND );
         r( wxSTC_GC_COMMENTBLOCK );
@@ -818,7 +755,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_HPHP_HSTRING_VARIABLE );
         r( wxSTC_HPHP_OPERATOR );
         r( wxSTC_HPHP_COMPLEX_VARIABLE );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_HA_CAPITAL );
         r( wxSTC_HA_CHARACTER );
         r( wxSTC_HA_CLASS );
@@ -836,7 +772,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_HA_NUMBER );
         r( wxSTC_HA_OPERATOR );
         r( wxSTC_HA_STRING );
-#endif
         break;
     case 'I':
         r( wxSTC_INDIC_MAX );
@@ -850,14 +785,9 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_INDIC2_MASK );
         r( wxSTC_INDICS_MASK );
         r( wxSTC_INDIC_BOX );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_INDIC_CONTAINER );
-#endif
         r( wxSTC_INDIC_HIDDEN );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_INDIC_ROUNDBOX );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_INNO_COMMENT );
         r( wxSTC_INNO_COMMENT_PASCAL );
         r( wxSTC_INNO_DEFAULT );
@@ -867,20 +797,15 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_INNO_KEYWORD_USER );
         r( wxSTC_INNO_PARAMETER );
         r( wxSTC_INNO_PREPROC );
-#if WXPERL_W_VERSION_LT( 2, 9, 1 )
-        r( wxSTC_INNO_PREPROC_INLINE );
-#endif
+        r( wxSTC_INNO_INLINE_EXPANSION );
         r( wxSTC_INNO_SECTION );
         r( wxSTC_INNO_STRING_DOUBLE );
         r( wxSTC_INNO_STRING_SINGLE );
         r( wxSTC_INVALID_POSITION );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_IV_LOOKBOTH );
         r( wxSTC_IV_LOOKFORWARD );
         r( wxSTC_IV_NONE );
         r( wxSTC_IV_REAL );
-#endif
         break;
     case 'K':
         r( wxSTC_KEY_DOWN );
@@ -901,11 +826,9 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_KEY_SUBTRACT );
         r( wxSTC_KEY_DIVIDE );
         r( wxSTC_KEYWORDSET_MAX );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_KEY_MENU );
         r( wxSTC_KEY_RWIN );
         r( wxSTC_KEY_WIN );
-#endif
         r( wxSTC_KIX_COMMENT );
         r( wxSTC_KIX_DEFAULT );
         r( wxSTC_KIX_FUNCTIONS );
@@ -937,9 +860,7 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_LEX_EIFFEL );
         r( wxSTC_LEX_EIFFELKW );
         r( wxSTC_LEX_ERRORLIST );
-#if WXPERL_W_VERSION_GE( 2, 5, 2 )
         r( wxSTC_LEX_FORTH );
-#endif
         r( wxSTC_LEX_FORTRAN );
         r( wxSTC_LEX_HTML );
         r( wxSTC_LEX_LATEX );
@@ -965,57 +886,35 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_LEX_SCRIPTOL );
         r( wxSTC_LEX_SQL );
         r( wxSTC_LEX_TCL );
-#if WXPERL_W_VERSION_GE( 2, 5, 2 )
         r( wxSTC_LEX_YAML );
         r( wxSTC_LEX_TEX );
-#endif
         r( wxSTC_LEX_VB );
         r( wxSTC_LEX_VBSCRIPT );
         r( wxSTC_LEX_XCODE );
         r( wxSTC_LEX_XML );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_LEX_ABAQUS );
-#endif
         r( wxSTC_LEX_APDL );
-#if WXPERL_W_VERSION_GE( 2, 6, 0 )
         r( wxSTC_LEX_ASN1 );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_LEX_ASYMPTOTE );
-#endif
         r( wxSTC_LEX_AU3 );
         r( wxSTC_LEX_BASH );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_LEX_BLITZBASIC );
         r( wxSTC_LEX_CAML );
         r( wxSTC_LEX_CLW );
-#endif
         r( wxSTC_LEX_CLWNOCASE );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_LEX_CMAKE );
-#endif
         r( wxSTC_LEX_CPPNOCASE );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_LEX_CSOUND );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_LEX_D );
-#endif
         r( wxSTC_LEX_ERLANG );
         r( wxSTC_LEX_ESCRIPT );
         r( wxSTC_LEX_F77 );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_LEX_FLAGSHIP );
         r( wxSTC_LEX_FREEBASIC );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_LEX_GAP );
-#endif
         r( wxSTC_LEX_GUI4CLI );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_LEX_HASKELL );
         r( wxSTC_LEX_INNOSETUP );
-#endif
         r( wxSTC_LEX_KIX );
         r( wxSTC_LEX_LOT );
         r( wxSTC_LEX_LOUT );
@@ -1023,36 +922,20 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_LEX_MMIXAL );
         r( wxSTC_LEX_MSSQL );
         r( wxSTC_LEX_OCTAVE );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_LEX_OPAL );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_LEX_PLM );
-#endif
         r( wxSTC_LEX_POV );
         r( wxSTC_LEX_POWERBASIC );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_LEX_PROGRESS );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_LEX_PUREBASIC );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_LEX_R );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_LEX_REBOL );
         r( wxSTC_LEX_SMALLTALK );
-#endif
         r( wxSTC_LEX_SPECMAN );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_LEX_SPICE );
         r( wxSTC_LEX_TADS3 );
-#endif
         r( wxSTC_LEX_VERILOG );
-#if WXPERL_W_VERSION_GE( 2, 6, 0 )
         r( wxSTC_LEX_VHDL );
-#endif
         r( wxSTC_LASTSTEPINUNDOREDO );
         r( wxSTC_L_DEFAULT );
         r( wxSTC_L_COMMAND );
@@ -1085,12 +968,10 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_LISP_STRINGEOL );
         r( wxSTC_LISP_IDENTIFIER );
         r( wxSTC_LISP_OPERATOR );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_LISP_KEYWORD_KW );
         r( wxSTC_LISP_MULTI_COMMENT );
         r( wxSTC_LISP_SPECIAL );
         r( wxSTC_LISP_SYMBOL );
-#endif
         r( wxSTC_LEXER_START );
         r( wxSTC_LOT_ABORT );
         r( wxSTC_LOT_BREAK );
@@ -1141,9 +1022,7 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_MARK_DOTDOTDOT );
         r( wxSTC_MARK_ARROWS );
         r( wxSTC_MARK_CHARACTER );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_MARK_FULLRECT );
-#endif
         r( wxSTC_MARK_PIXMAP );
         r( wxSTC_MARKNUM_FOLDEREND );
         r( wxSTC_MARKNUM_FOLDEROPENMID );
@@ -1155,10 +1034,8 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_MASK_FOLDERS );
         r( wxSTC_MARGIN_SYMBOL );
         r( wxSTC_MARGIN_NUMBER );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_MARGIN_BACK );
         r( wxSTC_MARGIN_FORE );
-#endif
         r( wxSTC_MOD_INSERTTEXT );
         r( wxSTC_MOD_DELETETEXT );
         r( wxSTC_MOD_CHANGESTYLE );
@@ -1208,10 +1085,8 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_MMIXAL_REGISTER );
         r( wxSTC_MMIXAL_STRING );
         r( wxSTC_MMIXAL_SYMBOL );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_MOD_CHANGEINDICATOR );
         r( wxSTC_MOD_CHANGELINESTATE );
-#endif
         r( wxSTC_MSSQL_COLUMN_NAME );
         r( wxSTC_MSSQL_COLUMN_NAME_2 );
         r( wxSTC_MSSQL_COMMENT );
@@ -1229,10 +1104,8 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_MSSQL_STRING );
         r( wxSTC_MSSQL_SYSTABLE );
         r( wxSTC_MSSQL_VARIABLE );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_MULTILINEUNDOREDO );
         r( wxSTC_MULTISTEPUNDOREDO );
-#endif
         break;
     case 'N':
         r( wxSTC_NNCRONTAB_DEFAULT );
@@ -1262,15 +1135,12 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_NSIS_MACRODEF );
         r( wxSTC_NSIS_STRINGVAR );
         r( wxSTC_NSIS_NUMBER );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_NSIS_COMMENTBOX );
         r( wxSTC_NSIS_FUNCTIONDEF );
         r( wxSTC_NSIS_PAGEEX );
         r( wxSTC_NSIS_SECTIONGROUP );
-#endif
         break;
     case 'O':
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_OPAL_BOOL_CONST );
         r( wxSTC_OPAL_COMMENT_BLOCK );
         r( wxSTC_OPAL_COMMENT_LINE );
@@ -1281,7 +1151,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_OPAL_SORT );
         r( wxSTC_OPAL_SPACE );
         r( wxSTC_OPAL_STRING );
-#endif
         r( wxSTC_OPTIONAL_START );
         break;
     case 'P':
@@ -1306,11 +1175,9 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_P_OPERATOR );
         r( wxSTC_P_IDENTIFIER );
         r( wxSTC_P_COMMENTBLOCK );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_P_STRINGEOL );
         r( wxSTC_P_DECORATOR );
         r( wxSTC_P_WORD2 );
-#endif
         r( wxSTC_PL_DEFAULT );
         r( wxSTC_PL_ERROR );
         r( wxSTC_PL_COMMENTLINE );
@@ -1341,23 +1208,17 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_PL_STRING_QX );
         r( wxSTC_PL_STRING_QR );
         r( wxSTC_PL_STRING_QW );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_PL_FORMAT );
         r( wxSTC_PL_FORMAT_IDENT );
         r( wxSTC_PL_SUB_PROTOTYPE );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_PL_POD_VERB );
         r( wxSTC_PL_VARIABLE_INDEXER );
-#endif
         r( wxSTC_PROPS_DEFAULT );
         r( wxSTC_PROPS_COMMENT );
         r( wxSTC_PROPS_SECTION );
         r( wxSTC_PROPS_ASSIGNMENT );
         r( wxSTC_PROPS_DEFVAL );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_PROPS_KEY );
-#endif
 
         r( wxSTC_PS_DEFAULT );
         r( wxSTC_PS_COMMENT );
@@ -1375,7 +1236,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_PS_HEXSTRING );
         r( wxSTC_PS_BASE85STRING );
         r( wxSTC_PS_BADSTRINGCHAR );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_PLM_COMMENT );
         r( wxSTC_PLM_CONTROL );
         r( wxSTC_PLM_DEFAULT );
@@ -1384,7 +1244,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_PLM_NUMBER );
         r( wxSTC_PLM_OPERATOR );
         r( wxSTC_PLM_STRING );
-#endif
         r( wxSTC_POV_BADDIRECTIVE );
         r( wxSTC_POV_COMMENT );
         r( wxSTC_POV_COMMENTLINE );
@@ -1404,7 +1263,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_POV_WORD8 );
         break;
     case 'R':
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_RB_BACKTICKS );
         r( wxSTC_RB_CHARACTER );
         r( wxSTC_RB_CLASSNAME );
@@ -1468,8 +1326,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_REBOL_WORD6 );
         r( wxSTC_REBOL_WORD7 );
         r( wxSTC_REBOL_WORD8 );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_R_BASEKWORD );
         r( wxSTC_R_COMMENT );
         r( wxSTC_R_DEFAULT );
@@ -1482,7 +1338,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_R_OTHERKWORD );
         r( wxSTC_R_STRING );
         r( wxSTC_R_STRING2 );
-#endif
         break;
     case 'S':
         r( wxSTC_STYLE_DEFAULT );
@@ -1492,16 +1347,12 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_STYLE_CONTROLCHAR );
         r( wxSTC_STYLE_INDENTGUIDE );
         r( wxSTC_STYLE_LASTPREDEFINED );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_STYLE_CALLTIP );
-#endif
         r( wxSTC_STYLE_MAX );
         r( wxSTC_SCMOD_SHIFT );
         r( wxSTC_SCMOD_CTRL );
         r( wxSTC_SCMOD_ALT );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_SCMOD_NORM );
-#endif
         r( wxSTC_SCRIPTOL_DEFAULT );
         r( wxSTC_SCRIPTOL_COMMENTLINE );
         r( wxSTC_SCRIPTOL_NUMBER );
@@ -1548,7 +1399,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_SN_WORD );
         r( wxSTC_SN_WORD2 );
         r( wxSTC_SN_WORD3 );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_SPICE_COMMENTLINE );
         r( wxSTC_SPICE_DEFAULT );
         r( wxSTC_SPICE_DELIMITER );
@@ -1598,15 +1448,10 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_ST_SUPER );
         r( wxSTC_ST_SYMBOL );
         r( wxSTC_START );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_STARTACTION );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 6, 0 )
         r( wxSTC_SEL_STREAM );
         r( wxSTC_SEL_RECTANGLE );
         r( wxSTC_SEL_LINES );
-#endif
 
         r( wxEVT_STC_CHANGE );
         r( wxEVT_STC_STYLENEEDED );
@@ -1621,9 +1466,6 @@ double stc_constant( const char* name, int arg )
         r( wxEVT_STC_MACRORECORD );
         r( wxEVT_STC_MARGINCLICK );
         r( wxEVT_STC_NEEDSHOWN );
-#if WXPERL_W_VERSION_LT( 2, 5, 2 )
-        r( wxEVT_STC_POSCHANGED );
-#endif
         r( wxEVT_STC_PAINTED );
         r( wxEVT_STC_USERLISTSELECTION );
         r( wxEVT_STC_URIDROPPED );
@@ -1639,19 +1481,14 @@ double stc_constant( const char* name, int arg )
         break;
     case 'T':
         r( wxSTC_TIME_FOREVER );
-#if WXPERL_W_VERSION_GE( 2, 5, 2 )
         r( wxSTC_TEX_DEFAULT );
         r( wxSTC_TEX_SPECIAL );
         r( wxSTC_TEX_GROUP );
         r( wxSTC_TEX_SYMBOL );
         r( wxSTC_TEX_COMMAND );
         r( wxSTC_TEX_TEXT );
-#endif
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_T3_BLOCK_COMMENT );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_T3_BRACE );
-#endif
         r( wxSTC_T3_DEFAULT );
         r( wxSTC_T3_D_STRING );
         r( wxSTC_T3_HTML_DEFAULT );
@@ -1693,12 +1530,10 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_TCL_WORD7 );
         r( wxSTC_TCL_WORD8 );
         r( wxSTC_TCL_WORD_IN_QUOTE );
-#endif
         break;
     case 'V':
         r( wxSTC_VISIBLE_SLOP );
         r( wxSTC_VISIBLE_STRICT );
-#if WXPERL_W_VERSION_GE( 2, 6, 0 )
         r( wxSTC_VHDL_ATTRIBUTE );
         r( wxSTC_VHDL_COMMENT );
         r( wxSTC_VHDL_COMMENTLINEBANG );
@@ -1714,7 +1549,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_VHDL_STRING );
         r( wxSTC_VHDL_STRINGEOL );
         r( wxSTC_VHDL_USERWORD );
-#endif
         r( wxSTC_V_COMMENT );
         r( wxSTC_V_COMMENTLINE );
         r( wxSTC_V_COMMENTLINEBANG );
@@ -1733,9 +1567,7 @@ double stc_constant( const char* name, int arg )
     case 'W':
         r( wxSTC_WRAP_NONE );
         r( wxSTC_WRAP_WORD );
-#if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_WRAP_CHAR );
-#endif
 
         r( wxSTC_WRAPVISUALFLAGLOC_DEFAULT );
         r( wxSTC_WRAPVISUALFLAGLOC_END_BY_TEXT );
@@ -1756,9 +1588,7 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_YAML_IDENTIFIER );
         r( wxSTC_YAML_KEYWORD );
         r( wxSTC_YAML_NUMBER );
-#if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_YAML_OPERATOR );
-#endif
         r( wxSTC_YAML_REFERENCE );
         r( wxSTC_YAML_TEXT );
         break;
